SmartDateFieldPickerState class

Inheritance

Constructors

SmartDateFieldPickerState()

Properties

contentKey GlobalKey<State<StatefulWidget>>
Key for the overlay content widget.
final
context BuildContext
The location in the tree where this widget builds.
no setterinherited
firstDate DateTime
getter/setter pair
focusNode FocusNode
Focus node used internally (optional, as widget may also provide it).
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isTypingDisabled bool
Flag to determine if typing should be disabled.
getter/setter pair
lastDate DateTime
getter/setter pair
Link between the text field and the overlay for correct positioning.
final
maskFormatter ↔ MaskTextInputFormatter
Formatter to enforce a DD/MM/YYYY date format.
getter/setter pair
mounted bool
Whether this State object is currently in a tree.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textController TextEditingController
Controller to manage the text inside the field.
final
textFieldKey GlobalKey<State<StatefulWidget>>
Key used to get the position of the text field.
final
widget SmartDateFieldPicker
The current configuration.
no setterinherited

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant SmartDateFieldPicker oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
override
Shows the dropdown if not already shown and field is editable.
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
textFiledOnTap() → void
Handles tap on the input field to show the date picker overlay.
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringShort() String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited