HeaderTheme class
Defines styling for the header area of the picker.
Constructors
- HeaderTheme({AlignmentGeometry? alignment, EdgeInsetsGeometry? headerMargin, EdgeInsetsGeometry? headerPadding, IconDecoration? iconDecoration, TextStyle? headerTextStyle, TextStyle? focusTextStyle, BoxDecoration? boxDecoration})
-
const
Properties
- alignment → AlignmentGeometry?
-
final
- boxDecoration → BoxDecoration?
-
final
- focusTextStyle → TextStyle?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerMargin → EdgeInsetsGeometry?
-
final
- headerPadding → EdgeInsetsGeometry?
-
final
- headerTextStyle → TextStyle?
-
final
- iconDecoration → IconDecoration?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{TextStyle? focusTextStyle, TextStyle? headerTextStyle, AlignmentGeometry? alignment, IconDecoration? iconDecoration, BoxDecoration? boxDecoration, EdgeInsetsGeometry? headerMargin, EdgeInsetsGeometry? headerPadding}) → HeaderTheme -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited